<template>
    <v-dialog
      v-model="view"
      persistent
      :max-width="600"
    >
        <dialog-layout  class="dark_dialog">
            <template v-slot:content>
                <h4 class="pb-2">Postcode</h4>
                <ValidationObserver ref="form">
                    <v-row >
                        <v-col cols="12">
                            <ValidationProvider name="Postcode" rules="required|digits:4" >
                                <v-text-field
                                    type="text"
                                    placeholder="Postcode"
                                    v-model="form.postcode"
                                    slot-scope="{errors}"
                                    :error-messages="errors"
                                    outlined
                                    class="white_textbox"

                                ></v-text-field>
                            </ValidationProvider>
                        </v-col>
                    </v-row>
                </ValidationObserver>
            </template>
            <template v-slot:actions>
                <v-row>
                    <v-col cols="12" class="p-0">
                        <v-btn
                        class="float-right black lighten--4 white--text"
                          depressed
                          @click="closeModel()"
                        >
                           Cancel
                        </v-btn>
                        <v-btn
                          depressed
                          class="float-right mr-2"
                          color="#FFFF00"
                          @click="setPostcode()"
                        >
                          Set Postcode
                        </v-btn>
                    </v-col>
                </v-row>
            </template>
        </dialog-layout>
        <location-confirmation ref="confirmation" 
           width="500"
           :confirm_button_color="'#FFFF00'"
           :cancel_button_color="'grey'"
           :show_close="confirmation.show_close"
           :confirm_button="confirmation.confirm_button"
           :msg="confirmation.msg" 
           @confirm="confirm()"
           @close="closeConfirmationModel()"
           ></location-confirmation>
    </v-dialog>
</template>
<script>
import LocationConfirmation from './LocationConfirmation.vue';
import DialogLayout from './Dialog.vue';
export default {
    components:{
        DialogLayout,LocationConfirmation
    },
    data() {
        return {
            view    : false,
            form    : this.getFormFields(),
            remove_location  :true,
            confirmation :{
                msg           : "",
                show_close    : true,
                confirm_button: "Ok"  
            },
        }
    },
    mounted() {
    },
    methods:{
        getFormFields() {
            return {
                postcode                : this.$store.state.front_end_data.postcode,
                location_id             : this.$store.state.front_end_data.location,
                current_postcode        : this.$store.state.front_end_data.postcode,
                current_location_id     : this.$store.state.front_end_data.location,
                is_new_location         : false
            }
        },
        openModel() {
            this.form = this.getFormFields();
            this.view = true;
        },
        closeModel() {
            this.view = false;
            this.form = this.getFormFields();
        },
        closeConfirmationModel() {
            this.$refs.confirmation.view = false;
            this.form = this.getFormFields();
        },
        confirm() {
            if(!this.confirmation.show_close) {
                this.$router.go();
            }
            else {
                this.setPostcode();
                this.$refs.confirmation.view = false;
            }
        },
        setPostcode() {
            this.$refs.form.validate().then(success=>{
                if(success) {
                    this.$axios.$post('/api/change-postcode',this.form)
                    .then(resp=>{
                        if(!resp.success) {
                            this.confirmation.msg = resp.error;
                            this.confirmation.confirm_button = "Ok";
                            if(resp.is_new_location) {
                                this.confirmation.confirm_button = "Redirect";
                            }
                            this.form.is_new_location = resp.is_new_location;
                            this.form.postcode = resp.postcode;
                            this.$refs.confirmation.view = true;
                            if(resp.reload_required) {
                                this.confirmation.show_close = false;
                            }
                        }
                        else {
                            this.$auth.$storage.setUniversal('postcode', resp.postcode);
                            this.$auth.$storage.setUniversal('location', resp.location_id);
                            this.$router.go();
                        }
                    })
                }
            });
        }
    }
}
</script>